package	jp.co.sds_corp.hibiya.threshold;

import java.util.Map;

import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;
import jp.co.sds_corp.util.script.IScriptParser;
import jp.co.sds_corp.util.script.ScriptParserFactory;

/**
JavaScriptを使用して、Checkerの状態を変更します。
呼び出し時に、JavaScriptの変数として以下のものが定義されます。
<TABLE BORDER="1">
<TR><TD>threshold</TD><TD>このThreshold自体</TD></TR>
<TR><TD>checker</TD><TD>対象の{@link IChecker}</TD></TR>
<TR><TD>results</TD><TD>{@link IChecker}のチェック結果が格納された{@link Map}</TD></TR>
</TABLE>
*/
public class ScriptThreshold extends AbstractThreshold
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	transient IScriptParser	parser;
	String	script;

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		parser = ScriptParserFactory.createParser( config );
		script = parser.getScript();
	}

	/**
	* 状態を取得します。
	* @return	状態
	*/
	public synchronized IChecker.Status getCheckerStatus( IChecker chk ) {
		IChecker.Status ret = chk.getCheckerStatus();
		try {
			if ( parser == null ||
				parser.getScript() == null || parser.getScript().length() == 0 )
			{
				return ret;
			}
			parser.setAttribute( "threshold", this );
			parser.setAttribute( "checker", chk );
			parser.setAttribute( "results", chk.getResults() );
			message = null;
			String res = parser.execute();
			ret = IChecker.Status.parse( res );
		} catch ( Exception ex ) {
			// logger.warn( "script execute error.", ex );
			if ( chk.getException() == null ) {
				chk.setException( ex );
			}
			ret = IChecker.Status.NG;
		} finally {
			try {
				parser.exit();
			} catch ( Exception ex ) {
			}
		}
		return ret;
	}

	/**
	* スクリプトを設定します。
	* @param	var		設定するスクリプト
	*/
	public void setScript( String var ) {
		this.script = var;
		if ( parser != null ) {
			parser.setScript( var );
		}
	}
	/**
	* スクリプトを取得します。
	* @return	スクリプト
	*/
	public String getScript() {
		return script;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param    config  設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		parser.saveConfig( config );
	}

}
