package	jp.co.sds_corp.hibiya.action;

import jp.co.sds_corp.hibiya.server.CheckerChangeEvent;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
受信したイベントを、Log4jを使用して保存するアクションです。
XMLは以下の形式です。
<TABLE BORDER="1">
	<TR><TH>要素</TH><TH>必須</TH><TH>説明</TH><TH>備考</TH></TR>
	<TR>
		<TD>Layout</TD><TD>&nbsp;</TD>
		<TD>formatに使用するLayout</TD>
		<TD>指定されない場合はメッセージのみ出力</TD>
	</TR>
</TABLE>
<PRE>
&lt;Action class="jp.co.sds_corp.hibiya.action.Log4jAction"&gt;
	&lt;Layout class="jp.co.sds_corp.hibiya.layout.EventLayout"&gt;
		%d %h %f:%p [%m]
	&lt;/Layout&gt;
&lt;/Action&gt;
</PRE>
*/
public class Log4jAction extends AbstractAction
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	String	config;

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		setConfig( config.get( "Config", null ));
	}

	/**
	* アクションを実行します。
	*/
	public void action( CheckerChangeEvent ev ) {
		String s;
		if ( getLayout() == null ) {
			s = ev.getMessage();
		} else {
			s = getLayout().format( ev );
		}
		if ( ev.getNewStatus() == IChecker.Status.NG ) {
			logger.error( this, s );
		} else {
			logger.info( this, s );
		}
	}

	/**
	* 設定内容の文字列表現を返します。
	*/
	public String paramString() {
		String ret = super.paramString();
		if ( config != null ) {
			ret += config;
		}
		return ret;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	親ノード
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		IConfiguration c;
		if ( getConfig() != null ) {
			c = config.addChild( "Config", getConfig() );
		}
	}

	/**
	* 設定ファイル名(config)を設定します。
	* @param	var		設定するデータ
	*/
	public void setConfig( String var ) {
		this.config = var ;
	}
	/**
	* 設定ファイル名(config)を取得します。
	* @return	fileの内容
	*/
	public String getConfig() {
		return config;
	}

}
